:html_theme.sidebar_secondary.remove:

CTAO Science Analysis Tools
===========================

**Version**: |version| **Date**: |today|

**Useful links**:
`CTAO <https://ctao.org>`_ |
`Installation <http://science-analysis-tools.gitlab-pages.cta-observatory.org/latest/getting-started.html>`_ |
`Source Repository <https://gitlab.cta-observatory.org/cta-computing/suss/science-analysis-tools/science-analysis-tools>`_ |
`Issue Tracker <https://gitlab.cta-observatory.org/cta-computing/suss/science-analysis-tools/science-analysis-tools/issues>`_ |
Q&A Support |


Welcome to the CTAO Science Analysis Tools (SAT) documentation.

Transform DL3 event lists and instrument response functions (IRFs) into high-level science products.

Built on `Gammapy <https://gammapy.org/>`_.


.. grid:: 1 2 2 2
   :gutter: 2

   .. grid-item-card::
      :text-align: center
      :columns: 12 6 6 6
      :shadow: md

      :octicon:`rocket;4em`

      **Getting started**

      How to install and start using ``ctao-sat``.

      +++

      .. button-ref:: getting-started
         :ref-type: ref
         :click-parent:
         :color: secondary
         :expand:

         To the quickstart docs

   .. grid-item-card::
      :text-align: center
      :columns: 12 6 6 6
      :shadow: md

      :octicon:`book;4em`

      **User guide**

      How to analyze CTAO data:
      examples and Jupyter notebooks tutorials.

      +++

      .. button-ref:: user_guide
         :ref-type: ref
         :click-parent:
         :color: secondary
         :expand:

         To the user guide


.. toctree::
    :titlesonly:
    :hidden:

    getting-started
    user-guide
    development
    changelog
